@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -173,6 +181,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "CN", "الصين" },
             { "CO", "كولومبيا" },
             { "CP", "جزيرة كليبيرتون" },
+            { "CQ", "سارك" },
             { "CR", "كوستاريكا" },
             { "CU", "كوبا" },
             { "CV", "الرأس الأخضر" },
@@ -471,7 +480,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "ko", metaValue_ko },
             { "kr", "الكانوري" },
             { "ks", "الكشميرية" },
-            { "ku", "الكردية" },
+            { "ku", "الكرمانجية" },
             { "kv", "الكومي" },
             { "kw", "الكورنية" },
             { "ky", "القيرغيزية" },
@@ -867,7 +876,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "sid", "السيدامو" },
             { "slh", "لوشوتسيد الجنوبية" },
             { "sma", "السامي الجنوبي" },
-            { "smj", "اللول سامي" },
+            { "smj", "السامي لولي" },
             { "smn", "الإيناري سامي" },
             { "sms", "السكولت سامي" },
             { "snk", "السونينك" },
@@ -1080,10 +1089,13 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "key.cf", "تنسيق العملة" },
             { "key.co", "ترتيب الفرز" },
             { "key.cu", "العملة" },
+            { "key.em", "عرض الرموز التعبيرية" },
             { "key.hc", "نظام التوقيت (12 مقابل 24)" },
             { "key.lb", "نمط فصل السطور" },
+            { "key.lw", "فصل السطور وسط الكلمات" },
             { "key.ms", "نظام القياس" },
             { "key.nu", "الأرقام" },
+            { "key.ss", "فاصل الجملة بعد الاختصار" },
             { "key.tz", "المنطقة الزمنية" },
             { "key.va", "متغيرات اللغة" },
             { "nds_NL", "السكسونية السفلى" },
@@ -1166,7 +1178,6 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "type.ca.iso8601", "تقويم ISO-8601" },
             { "type.ca.persian", "التقويم الفارسي" },
             { "type.cf.account", "تنسيق العملة للحسابات" },
-            { "type.co.big5han", "الترتيب حسب اللغة الصينية التقليدية (Big5)" },
             { "type.d0.npinyin", "رقمي" },
             { "type.nu.arabext", "الأرقام العربية الهندية الممتدة" },
             { "type.nu.armnlow", "الأرقام الأرمينية الصغيرة" },
@@ -1189,7 +1200,6 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "type.nu.fullwide", "أرقام كاملة العرض" },
             { "type.nu.romanlow", "الأرقام الرومانية الصغيرة" },
             { "type.ca.gregorian", "التقويم الميلادي" },
-            { "type.co.gb2312han", "الترتيب حسب اللغة الصينية المبسّطة (GB2312)" },
             { "type.co.phonebook", "الترتيب حسب دليل الهاتف" },
             { "type.co.dictionary", "الترتيب حسب القاموس" },
             { "type.co.traditional", "ترتيب تقليدي" },
