@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -150,6 +158,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "CN", "Hytaý" },
             { "CO", "Kolumbiýa" },
             { "CP", "Klipperton adasy" },
+            { "CQ", "Sark" },
             { "CR", "Kosta-Rika" },
             { "CU", "Kuba" },
             { "CV", "Kabo-Werde" },
@@ -443,7 +452,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ko", "koreý dili" },
             { "kr", "kanuri" },
             { "ks", "kaşmiri dili" },
-            { "ku", "kürt dili" },
+            { "ku", "kurmanji dili" },
             { "kv", "komi dili" },
             { "kw", "korn dili" },
             { "ky", "gyrgyz dili" },
@@ -483,7 +492,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "os", "osetin dili" },
             { "pa", "penjab dili" },
             { "pl", "polýak dili" },
-            { "ps", "peştun dili" },
+            { "ps", "puştu dili" },
             { "pt", "portugal dili" },
             { "qu", "keçua dili" },
             { "rm", "retoroman dili" },
@@ -552,6 +561,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ast", "asturiý dili" },
             { "atj", "atikamekw dili" },
             { "awa", "awadhi dili" },
+            { "bal", "buluç dili" },
             { "ban", "baliý dili" },
             { "bas", "basaa dili" },
             { "bem", "bemba dili" },
@@ -716,7 +726,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "pcm", "nigeriýa-pijin dili" },
             { "pis", "pijin dili" },
             { "pqm", "malisit-passamakwodi dili" },
-            { "prg", "prussiýa dili" },
+            { "prg", "prus dili" },
             { "quc", "kiçe dili" },
             { "raj", "rajastani dili" },
             { "rap", "rapanuý dili" },
@@ -862,10 +872,13 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "key.cf", "Pul birliginiň formaty" },
             { "key.co", "Tertip rejesi" },
             { "key.cu", "Pul birligi" },
+            { "key.em", "Emoji aňlatmasy" },
             { "key.hc", "Sagat aýlawy (12–24 sagat)" },
             { "key.lb", "Setirden setire geçiş stili" },
+            { "key.lw", "Sözleriň içinde setir bölünmeleri" },
             { "key.ms", "Ölçeg ulgamy" },
             { "key.nu", "Sanlar" },
+            { "key.ss", "Gysgaltmadan soň sözlemi bölmek" },
             { "zh_Hans", "ýönekeýleşdirilen hytaý dili" },
             { "zh_Hant", "adaty hytaý dili" },
             { "type.ca.roc", "Minguo senenamasy" },
