@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -338,6 +346,14 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Hawaii = new String[] {
+               "Hawaii-Aleutian Standard Time",
+               "HST",
+               "",
+               "HST",
+               "",
+               "HST",
+            };
         final String[] Israel = new String[] {
                "Israel Standard Time",
                "IST",
@@ -666,14 +682,6 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Sakhalin = new String[] {
-               "Sakhalin Standard Time",
-               "",
-               "Sakhalin Summer Time",
-               "",
-               "Sakhalin Time",
-               "",
-            };
         final String[] Suriname = new String[] {
                "Suriname Time",
                "",
@@ -770,14 +778,6 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Volgograd = new String[] {
-               "Volgograd Standard Time",
-               "MSK",
-               "Volgograd Summer Time",
-               "MSK",
-               "Volgograd Time",
-               "MSK",
-            };
         final String[] Azerbaijan = new String[] {
                "Azerbaijan Standard Time",
                "",
@@ -866,14 +866,6 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
                "New Zealand Time",
                "NZT",
             };
-        final String[] Novosibirsk = new String[] {
-               "Novosibirsk Standard Time",
-               "",
-               "Novosibirsk Summer Time",
-               "",
-               "Novosibirsk Time",
-               "",
-            };
         final String[] Philippines = new String[] {
                "Philippine Standard Time",
                "PST",
@@ -971,12 +963,12 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
                "EAT",
             };
         final String[] Africa_Western = new String[] {
-               "West Africa Standard Time",
-               "WAT",
-               "West Africa Summer Time",
-               "WAT",
                "West Africa Time",
                "WAT",
+               "",
+               "WAT",
+               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Dumont-d’Urville Time",
@@ -1070,9 +1062,9 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
                "Hawaii-Aleutian Standard Time",
                "HST",
                "Hawaii-Aleutian Daylight Time",
-               "HST",
+               "HDT",
                "Hawaii-Aleutian Time",
-               "HST",
+               "HT",
             };
         final String[] Phoenix_Islands = new String[] {
                "Phoenix Islands Time",
@@ -1177,7 +1169,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
-            { "Pacific/Honolulu", Hawaii_Aleutian },
+            { "Pacific/Honolulu", Hawaii },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
@@ -1216,7 +1208,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "ECT", Europe_Central },
             { "EET", Europe_Eastern },
             { "EST", America_Eastern },
-            { "HST", Hawaii_Aleutian },
+            { "HST", Hawaii },
             { "IET", America_Eastern },
             { "IST", India },
             { "JST", Japan },
@@ -1330,7 +1322,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Kwajalein", Marshall_Islands },
             { "Singapore", Singapore },
             { "US/Alaska", Alaska },
-            { "US/Hawaii", Hawaii_Aleutian },
+            { "US/Hawaii", Hawaii },
             { "Universal",
                 new String[] {
                     "Coordinated Universal Time",
@@ -1351,6 +1343,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "Asia/Tomsk", Krasnoyarsk },
             { "US/Arizona", America_Mountain },
             { "US/Central", America_Central },
             { "US/Eastern", America_Eastern },
@@ -1398,6 +1391,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Asia/Baghdad", Arabian },
             { "Asia/Bahrain", Arabian },
             { "Asia/Bangkok", Indochina },
+            { "Asia/Barnaul", Krasnoyarsk },
             { "Asia/Bishkek", Kyrgystan },
             { "Asia/Colombo", India },
             { "Asia/Irkutsk", Irkutsk },
@@ -1413,6 +1407,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
             { "Canada/Yukon", Yukon },
+            { "Europe/Kirov", Moscow },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1459,7 +1454,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
             { "Asia/Qostanay", Kazakhstan },
-            { "Asia/Sakhalin", Sakhalin },
+            { "Asia/Sakhalin", Magadan },
             { "Asia/Tashkent", Uzbekistan },
             { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
@@ -1527,7 +1522,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
             { "Pacific/Samoa", Samoa },
-            { "SystemV/HST10", Hawaii_Aleutian },
+            { "SystemV/HST10", Hawaii },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1557,6 +1552,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
             { "Asia/Chungking", China },
+            { "Asia/Famagusta", Europe_Eastern },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
@@ -1701,7 +1697,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Antarctica/Troll", GMT },
             { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
-            { "Asia/Novosibirsk", Novosibirsk },
+            { "Asia/Novosibirsk", Krasnoyarsk },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Vladivostok", Vladivostok },
             { "Atlantic/Bermuda", Atlantic },
@@ -1718,14 +1714,14 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
-            { "Europe/Volgograd", Volgograd },
+            { "Europe/Volgograd", Moscow },
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
             { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
-            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "Pacific/Johnston", Hawaii },
             { "Pacific/Pitcairn", Pitcairn },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
@@ -1783,6 +1779,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Srednekolymsk", Magadan },
             { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
@@ -1874,7 +1871,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Saigon", "Ho Chi Minh City" },
-            { "timezone.excity.Etc/Unknown", "Unknown City" },
+            { "timezone.excity.Etc/Unknown", "Indawo Engaziwayo" },
             { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "America/Argentina/Buenos_Aires", Argentina },
@@ -1882,6 +1879,7 @@ public class TimeZoneNames_xh extends TimeZoneNamesBundle {
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.America/Cancun", "Cancun" },
             { "timezone.excity.America/Merida", "Merida" },
+            { "timezone.excity.Pacific/Enderbury", "ICanton Island" },
             { "timezone.excity.America/Bahia_Banderas", "Bahia Banderas" },
         };
         return data;
